<?php
namespace Planejamento\Logic;
/**
 * FPA.
 *
 * @package Logic
 * @author  alessandrobartels
 *
 */
class FPA {

    const NRORG_PADRAO = 'NRORG_PADRAO';
    const NRORG_TRAB = 'NRORG_TRAB';
    const ESTRUTURA_TRAB = 'ESTRUTURA_TRAB';
    const TIPO_ESTRUTURA_LEGAL = 'TIPO_ESTRUTURA_LEGAL';
    const TIPO_ESTRUTURA_GERENCIAL = 'TIPO_ESTRUTURA_GERENCIAL';
    const MES_COMPETENCIA = 'MES_COMPETENCIA';
    const ULTIMO_DIA_MES = 'ULTIMO_DIA_MES';
    const MOD_CALCULO = 'MOD_CALCULO';
    const MOD_SALARIO = 'MOD_SALARIO';
    const OCORRENCIA_CALCULO = 'OCORRENCIA_CALCULO';
    const TIPO_OPERADOR = 'TIPO_OPERADOR';


    /**
     * Determina numero de calculo de folha.
     *
     * @param string $nrOrg         Numero da Organizacao.
     * @param string $tipoMovimento Tipo de Movimento.
     * @param string $cdOperador    Codigo do operador.
     *
     * @return integer
     */
    public static function determinaNrCalculoFolha($nrOrg, $tipoMovimento, $cdOperador) {

        /* Passar para o FpacalculofolhaFacade */

        $parametro = new Parametros($nrOrg, $cdOperador);
        $mesCompetencia = $parametro->getMesCompetencia();
        $nrOrgTrabalho = $parametro->getNrOrgTrabalho();
        $nrTpModalidadeCalc = $parametro->getTipoModalidadeCalculo();
        $nrOcorrenciaCalc = $parametro->getNrOcorrenciaCalculo();

        $calculoFolha = new FpacalculofolhaEntity();
        $calcFolha = current(
            $calculoFolha->retornaCalculoFolha(
                $nrOrgTrabalho, $tipoMovimento, $mesCompetencia, $nrTpModalidadeCalc, $nrOcorrenciaCalc
            )
        );

        unset($parametro);
        return $calcFolha->getNrcalculofolha();
    }


    /**
     * Determina data de alteracao salarial.
     *
     * @param string $nrorg Numero da Organizacao.
     *
     * @return TkDateTime
     */
    public static function determinaDataAlteracaoSalarial($nrorg){
        $parametro = new Parametros();
        $data = $parametro->dataAlteracaoSalarial($nrorg);
        return $data;
    }


    /**
     * Constroi string para informacao em tela.
     *
     * @param string $nrOrg      Numero da organizacao.
     * @param string $cdOperador Codigo do operador.
     *
     * @return void
     *
     * @author alessandrobartels - 15/06/2011
     */
    public static function determinaInformacoesTela($nrOrg, $cdOperador){
        $parametro = new Parametros($nrOrg, $cdOperador);
        $nrOrgPadrao = $parametro->getNrOrgPadrao();
        $nrOrgTrabalho = $parametro->getNrOrgTrabalho();
        $nrEstrutTrab = $parametro->getNrEstrutTrab();
        $tpEstrutLegal = $parametro->getTipoEstruturaLegal();
        $tpEstrutGerencial = $parametro->getTipoEstruturaGerencial();
        $mesCompetencia = $parametro->getMesCompetencia();
        $modCalculo = $parametro->getDescricaoTipoModalidadeCalculo();
        $modSalario = $parametro->getDescricaoTipoModalidadeSalario();
        $ocorrenciaCalculo = $parametro->getNrOcorrenciaCalculo();

        //$tipoOperador = $parametro->getTipoOperador();

        self::atribuiVariaveisAmbiente(
            $nrOrgTrabalho, $nrOrgPadrao, $mesCompetencia, $modCalculo, $modSalario, $ocorrenciaCalculo, $nrEstrutTrab,
            $tpEstrutLegal, $tpEstrutGerencial
        );


       /*  $info = "<b>TESTE</b>";
         tk_set_user_info($info);
        */
        /*
        // Inverte o mes com o dia.
        list($dia, $mes, $ano) = split('[/.-]', $mesCompetencia);
        list($ano, $hora) = split(' ', $ano);
        $mesCompetencia = $mes.'/'.$dia.'/'.$ano;

        // Retorna dados da organizacao de trabalho.
        $organizacao = new OrganizacaoEntity();
        $orgTrabalho = $organizacao->retornaOrganizacao($nrOrgTrabalho);

        // Pega os dados gerais.
        $informacaoInicial = tk_get_env_var('INFORMACAO_TELA', null, 'FPA');
        // Concatena dados do projeto FPA na string.
        $informacao = $informacaoInicial;
        $informacao .= '<br/>Org. de Trabalho: '.$orgTrabalho->getNmorganizacao();
        $informacao .= '<br/>Compet�ncia: ';
        $informacao .= strftime('%b', strtotime($mesCompetencia)).'/'.strftime('%Y', strtotime($mesCompetencia));
        $informacao = '<span>'.$informacao.'</span>';
        return  utf8_encode($informacao);
        */

    }


    /**
     * Atribui variavies ao ambiente de Calculo.
     *
     * @param integer $nrOrgTrab         Numero da Org. de Trabalho.
     * @param integer $nrOrgPadrao       Numero da Org. Padrao.
     * @param string  $mesCompetencia    Data de competencia.
     * @param string  $modCalculo        Modalidade de Calculo.
     * @param string  $modSalario        Modaliadde de Salario.
     * @param integer $ocorrenciaCalculo Ocorrencia de Calculo.
     * @param string  $tipoOperador      Tipo de Operador.
     *
     * @return void
     */
    public static function atribuiVariaveisAmbiente(
        $nrOrgTrab, $nrOrgPadrao, $mesCompetencia, $modCalculo, $modSalario, $ocorrenciaCalculo, $nrEstruttrab,
        $tpEstrutLegal, $tpEstrutGerencial
    ){
        tk_set_env_var(self::NRORG_PADRAO, $nrOrgPadrao);
        tk_set_env_var(self::NRORG_TRAB, $nrOrgTrab);
        tk_set_env_var(self::ESTRUTURA_TRAB, $nrEstruttrab);
        tk_set_env_var(self::TIPO_ESTRUTURA_LEGAL, $tpEstrutLegal);
        tk_set_env_var(self::TIPO_ESTRUTURA_GERENCIAL, $tpEstrutGerencial);
        tk_set_env_var(self::MES_COMPETENCIA, $mesCompetencia);
        tk_set_env_var(self::MOD_CALCULO, $modCalculo);
        tk_set_env_var(self::MOD_SALARIO, $modSalario);
        tk_set_env_var(self::OCORRENCIA_CALCULO, $ocorrenciaCalculo);

        $dtUltDiaMes = new TkDateTime($mesCompetencia);
        $dtUltDiaMes->setDay(1)->addMonth(1)->subDay(1);
        tk_set_env_var(self::ULTIMO_DIA_MES, $dtUltDiaMes);

        //tk_set_env_var(self::TIPO_OPERADOR, $tipoOperador);

        Ambiente::setNrorgSelecionada($nrOrgTrab);
    }



    /**
     * Converta parte de minuto da hora em decimal (depois da virgula)
     * @static
     *
     * @param $hora
     *
     * @return float
     */
    public static function converteHoraDecimal($hora){

        $aux = floor($hora);

        if ($aux === $hora){
            return $hora;
        } else {
            $minuto = $hora - $aux;
            $decimal = $minuto * 100.0 / 60.0;
            $aux += $decimal;

            return $aux;
        }
    }


}
/* Fim de arquivo.*/